@@ -6,7 +6,8 @@
 
 
 ## get a summary of an object for a list of lines:
-setMethod("count", signature(x = "GridTopology"), function(x, vectL, ...){
+count.GridTopology <- function(x, vectL, ...){
+    if(any(class(x)=="GridTopology")){    
     # rasterize each line separately:
     sg <- SpatialGridDataFrame(x, proj4string = vectL[[1]]@proj4string, data=data.frame(observed=rep(NA, x@cells.dim[1]*x@cells.dim[2]), observed.sd=rep(NA, x@cells.dim[1]*x@cells.dim[2])))
     xv <- NULL
@@ -22,6 +23,9 @@ setMethod("count", signature(x = "GridTopology"), function(x, vectL, ...){
     sg$observed.sd <- ifelse(sg$observed==0|sg$observed==1, 0, -sg$observed*log2(sg$observed)-(1-sg$observed)*log2(1-sg$observed))  ## information entropy (H) of a Bernoulli trial 
     out = new("SpatialVectorsSimulations", realizations = vectL, summaries = sg)
     return(out)
-})
+    } else {
+      stop("Object of class 'GridTopology' required")
+    }
+}
 
 ## end of script;
\ No newline at end of file
