@@ -12,7 +12,7 @@ kml.Spatial <- function(
   ...
 ){
 
-  kml_open(folder.name = folder.name, file.name = file.name, ...)
+  kml_open(folder.name = folder.name, file.name = file.name)
 
   kml_layer(obj = obj, ...)
 
